import matplotlib.pyplot as plt
import numpy as np
import matplotlib as mpl

mpl.rcParams['font.family'] = 'sans-serif'
mpl.rcParams['lines.linewidth'] = 2
mpl.rcParams['lines.markersize'] = 8
mpl.rcParams['font.size'] = 25 
mpl.rcParams['legend.fontsize'] = 20
mpl.rcParams['axes.titlesize'] = 28
mpl.rcParams['axes.labelsize'] = 25
mpl.rcParams['xtick.major.size'] = 10
mpl.rcParams['ytick.major.size'] = 10
mpl.rcParams['xtick.major.width'] = 1
mpl.rcParams['ytick.major.width'] = 1
mpl.rcParams['xtick.direction'] = 'inout'
mpl.rcParams['ytick.direction'] = 'inout'
mpl.rcParams['figure.titlesize'] = 28
mpl.rcParams['figure.figsize'] = [10.,7.0]


# Function to calculate density
def Rho(Temp, mu, U):
    beta = 1./Temp
    Z = np.exp(-beta*U/4.) + 2.*np.exp(+beta*(U/4.+mu))+np.exp(-beta*(U/4.-2.*mu))
    return 2./Z*(np.exp(-beta*(-U/4.-mu))+np.exp(-beta*(U/4.-2.*mu)))

# Function to calculate double occupancy
def Double_occ(Temp, mu, U):
    beta = 1./Temp
    Z = np.exp(-beta*U/4.) + 2.*np.exp(+beta*(U/4.+mu))+np.exp(-beta*(U/4-2.*mu))
    return 1./Z*(np.exp(-beta*(U/4.-2.*mu)))


MU = np.linspace(-6.,6.,1000)

plt.plot(MU, Rho(2.,MU, 4.), label="T=2.0")
plt.plot(MU, Rho(0.5,MU, 4.), label="T=0.5")
plt.plot(MU, Rho(0.25,MU, 4.), label="T=0.25")
plt.xlabel(r"$\mathrm{\mu}$")
plt.ylabel(r"$\mathrm{\rho(\mu)}$")
plt.xlim(-6,6)
plt.legend()
plt.show()


MU1= np.linspace(-6.,6.,999)

plt.plot(MU1, np.diff(Rho(2.,MU, 4.))/np.diff(MU), label="T=2.0")
plt.plot(MU1, np.diff(Rho(0.5,MU, 4.))/np.diff(MU), label="T=0.5")
plt.plot(MU1, np.diff(Rho(0.25,MU, 4.))/np.diff(MU), label="T=0.25")
plt.xlabel(r"$\mathrm{\mu}$")
plt.ylabel(r"$\mathrm{\frac{\partial \rho}{\partial \mu}}$")
plt.xlim(-6,6)
plt.legend()
plt.show()


UU = np.linspace(0.0,12.,1000)

plt.plot(UU, Rho(2., 0.0, UU)-2.*Double_occ(2.0, 0.0, UU), UU, [1.]*1000, "k--")
plt.xlabel(r"$\mathrm{U}$")
plt.ylabel(r"$\mathrm{<m^2>}$")
plt.xlim(0.0,12.0)
plt.show()


TT = np.linspace(0.01 ,6.,1000)

plt.plot(TT, Rho(TT, 0.0, 4.)-2.*Double_occ(TT, 0.0, 4.), UU, [1.]*1000, "k--")
plt.xlabel(r"$\mathrm{T}$")
plt.ylabel(r"$\mathrm{<m^2>}$")
plt.xlim(0.0,6.0)
plt.show()